==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_ay.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=ay
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'jutir yatiyawinakaruki (pirwa yatiyawinak janiw mayjt’aykiti)',
	'bouton_radio_articles_tous' => 'taqpach qillqatanakaru',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'Taqpach qillqatanakaru, janiw jiwt’at aruskipañanakar ukhama.',
	'bouton_radio_enregistrement_obligatoire' => 'Qillqaw mayita (qillqayasiñapuniw aruskipayir churasina janir aruskipañan arst’asa)',
	'bouton_radio_modere_abonnement' => 'qillqatanakatakiki',
	'bouton_radio_modere_posteriori' => 'qhipurunx k’achata', # MODIF
	'bouton_radio_modere_priori' => 'nayraqatax k’achata', # MODIF
	'bouton_radio_publication_immediate' => 'Yatiyawinakat jank’aki yatiyaña (apayasinxa yanapawinakaxa uñstapxiwa, apnaqawirit ukata qhipurunxa apaqataspawa)',

	// F
	'form_pet_message_commentaire' => '¿Mä yatiyawi, mä amuyu?',
	'forum' => 'Aruskipaña',
	'forum_acces_refuse' => 'Aka aruskipañaru janiw mantawimax utjiti.',
	'forum_attention_dix_caracteres' => '<b>¡Amuyam!</b>  tunka qillqaniñapakikiw yatiyawimanx utjañapawa.',
	'forum_attention_trois_caracteres' => '&lt;b&gt;¡Uñjam!&lt;/b&gt; Kimsa qillqaniñapakikiw sutinchatanx utjañapawa.',
	'forum_attention_trop_caracteres' => '<b>¡Amuyam!</b> Amuyam yatiyawimax sinti jac’hawa (@compte@ qillqanaka) qillqayañatakixa, qillqanakax janiw jilanchjañapakiti @max@.', # MODIF
	'forum_avez_selectionne' => 'Ajlltawa:',
	'forum_cliquer_retour' => 'Sarantaskakiñatakix limt’am &lt;a href=’@retour_forum@’&gt;akjaru&lt;/a&gt;.   ',
	'forum_forum' => 'Aruskipaña',
	'forum_info_modere' => 'Nayraqatax aka aruskipañax t’akutaw: Arst’añamax janiw uñstkaniti iyawsan ukjakama qamawin apnaqiri jupanakampi.', # MODIF
	'forum_lien_hyper' => 'Jach’a sawuta chinu mayachawi (ajlliñatakiwa)', # MODIF
	'forum_message_definitif' => 'Yatiyawi: qamawir apayaña',
	'forum_message_trop_long' => 'Yatiyawimax sinti jach’awa. Pä tunk waranq qillqanakaniñapawa', # MODIF
	'forum_ne_repondez_pas' => 'Aka aruskipayirirux jan jaysamti, jan ukjax aruskipañar jaysam aka utjawiru:', # MODIF
	'forum_page_url' => '(Sitix yatiyawimax mä qillqat yatiyatar aytata internetan, jan ukjax kawkintix mä laphi uñnaqan kunantix juk’amp yatiyawinak utjkisa, ukjarux laphi uñnaqan sutinchap ukhamarak URL utjawip uñachayam)',
	'forum_poste_par' => 'Yatiyaw apayata @parauteur@ qillqatar jaysayañjama @titre@', # MODIF
	'forum_qui_etes_vous' => '¿Khititasa? (ajlliñatakiwa)', # MODIF
	'forum_texte' => 'Yatiyawiman sawu:', # MODIF
	'forum_titre' => 'Sutichata:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Ajllita yaw saña',
	'forum_voir_avant' => 'Janir apaykasin aka yatiyaw uñjaña', # MODIF
	'forum_votre_email' => 'Aruskipayiriman utjawipa:', # MODIF
	'forum_votre_nom' => 'Sutima (jan ukjax sutichawima):', # MODIF
	'forum_vous_enregistrer' => 'Aka aruskipañan arsuñatakix, naraqatax qillqayasisma. Ukjarux juman uñt’irim churapksma uñachawimatxa yuspagara. Jan qillqataktax ukjax, ',
	'forum_vous_inscrire' => 'qillqayasiñama.',

	// I
	'icone_poster_message' => 'Mä yatiyawi apayaña',
	'icone_suivi_forum' => 'Jichhaptat aruskiñat yatiyata: @nb_forums@yanapawinaka',
	'icone_suivi_forums' => 'Aruskipañanak apnaqaña ukhamarak uñch’ukiña',
	'icone_supprimer_message' => 'Aka yatiyaw apaqaña',
	'icone_valider_message' => 'Aka yatiyaw iyaw saña',
	'info_appliquer_choix_moderation' => 'Aka amuya kasta luraña',
	'info_desactiver_forum_public' => 'Aruskipañanak jiwt’ayaña. Qillqatanakatakikiw naktayatani, ukhamarusa janiw jisk’aptatanakataki t’aqanakatakiraki.',
	'info_envoi_forum' => 'Aruskipañanakat uñch’ukiwi',
	'info_fonctionnement_forum' => 'Aruskipañawit lurt’xawipa:',
	'info_gauche_suivi_forum_2' => 'Web qamawixa <i>aruskipañawinakat uñch’ukiwi</i> mä irnaqañatak qamawimat apnaqawiwa ( janiw aruskipaw qamawxakiti ukhamarak janiw qillqayaw qamawxakiti). Taqpach yanapanaka aruskipañawinakat aka qillqatata ukhamarak apnaqayaraktamwa.', # MODIF

	// O
	'onglet_messages_internes' => 'Manqhat yatiyawinaka',
	'onglet_messages_publics' => 'Yatiyawinak taqinir uñt’ayañataki ',
	'onglet_messages_vide' => 'Jan sawump yatiyawinaka',

	// R
	'repondre_message' => 'Aka yatiyawir jaysaña',

	// S
	'statut_original' => 'nayriri',

	// T
	'titre_forum' => 'Manqha aruskipañawi'
);

==> spip_4.2.14+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_ay.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=ay
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'jutir yatiyawinakaruki (pirwa yatiyawinak janiw mayjt’aykiti)',
	'bouton_radio_articles_tous' => 'taqpach qillqatanakaru',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'Taqpach qillqatanakaru, janiw jiwt’at aruskipañanakar ukhama.',
	'bouton_radio_enregistrement_obligatoire' => 'Qillqaw mayita (qillqayasiñapuniw aruskipayir churasina janir aruskipañan arst’asa)',
	'bouton_radio_modere_abonnement' => 'qillqatanakatakiki',
	'bouton_radio_modere_posteriori' => 'qhipurunx k’achata', # MODIF
	'bouton_radio_modere_priori' => 'nayraqatax k’achata', # MODIF
	'bouton_radio_publication_immediate' => 'Yatiyawinakat jank’aki yatiyaña (apayasinxa yanapawinakaxa uñstapxiwa, apnaqawirit ukata qhipurunxa apaqataspawa)',

	// F
	'form_pet_message_commentaire' => '¿Mä yatiyawi, mä amuyu?',
	'forum' => 'Aruskipaña',
	'forum_acces_refuse' => 'Aka aruskipañaru janiw mantawimax utjiti.',
	'forum_attention_dix_caracteres' => '<b>¡Amuyam!</b>  tunka qillqaniñapakikiw yatiyawimanx utjañapawa.',
	'forum_attention_trois_caracteres' => '&lt;b&gt;¡Uñjam!&lt;/b&gt; Kimsa qillqaniñapakikiw sutinchatanx utjañapawa.',
	'forum_attention_trop_caracteres' => '<b>¡Amuyam!</b> Amuyam yatiyawimax sinti jac’hawa (@compte@ qillqanaka) qillqayañatakixa, qillqanakax janiw jilanchjañapakiti @max@.', # MODIF
	'forum_avez_selectionne' => 'Ajlltawa:',
	'forum_cliquer_retour' => 'Sarantaskakiñatakix limt’am &lt;a href=’@retour_forum@’&gt;akjaru&lt;/a&gt;.   ',
	'forum_forum' => 'Aruskipaña',
	'forum_info_modere' => 'Nayraqatax aka aruskipañax t’akutaw: Arst’añamax janiw uñstkaniti iyawsan ukjakama qamawin apnaqiri jupanakampi.', # MODIF
	'forum_lien_hyper' => 'Jach’a sawuta chinu mayachawi (ajlliñatakiwa)', # MODIF
	'forum_message_definitif' => 'Yatiyawi: qamawir apayaña',
	'forum_message_trop_long' => 'Yatiyawimax sinti jach’awa. Pä tunk waranq qillqanakaniñapawa', # MODIF
	'forum_ne_repondez_pas' => 'Aka aruskipayirirux jan jaysamti, jan ukjax aruskipañar jaysam aka utjawiru:', # MODIF
	'forum_page_url' => '(Sitix yatiyawimax mä qillqat yatiyatar aytata internetan, jan ukjax kawkintix mä laphi uñnaqan kunantix juk’amp yatiyawinak utjkisa, ukjarux laphi uñnaqan sutinchap ukhamarak URL utjawip uñachayam)',
	'forum_poste_par' => 'Yatiyaw apayata @parauteur@ qillqatar jaysayañjama @titre@', # MODIF
	'forum_qui_etes_vous' => '¿Khititasa? (ajlliñatakiwa)', # MODIF
	'forum_texte' => 'Yatiyawiman sawu:', # MODIF
	'forum_titre' => 'Sutichata:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Ajllita yaw saña',
	'forum_voir_avant' => 'Janir apaykasin aka yatiyaw uñjaña', # MODIF
	'forum_votre_email' => 'Aruskipayiriman utjawipa:', # MODIF
	'forum_votre_nom' => 'Sutima (jan ukjax sutichawima):', # MODIF
	'forum_vous_enregistrer' => 'Aka aruskipañan arsuñatakix, naraqatax qillqayasisma. Ukjarux juman uñt’irim churapksma uñachawimatxa yuspagara. Jan qillqataktax ukjax, ',
	'forum_vous_inscrire' => 'qillqayasiñama.',

	// I
	'icone_poster_message' => 'Mä yatiyawi apayaña',
	'icone_suivi_forum' => 'Jichhaptat aruskiñat yatiyata: @nb_forums@yanapawinaka',
	'icone_suivi_forums' => 'Aruskipañanak apnaqaña ukhamarak uñch’ukiña',
	'icone_supprimer_message' => 'Aka yatiyaw apaqaña',
	'icone_valider_message' => 'Aka yatiyaw iyaw saña',
	'info_appliquer_choix_moderation' => 'Aka amuya kasta luraña',
	'info_desactiver_forum_public' => 'Aruskipañanak jiwt’ayaña. Qillqatanakatakikiw naktayatani, ukhamarusa janiw jisk’aptatanakataki t’aqanakatakiraki.',
	'info_envoi_forum' => 'Aruskipañanakat uñch’ukiwi',
	'info_fonctionnement_forum' => 'Aruskipañawit lurt’xawipa:',
	'info_gauche_suivi_forum_2' => 'Web qamawixa <i>aruskipañawinakat uñch’ukiwi</i> mä irnaqañatak qamawimat apnaqawiwa ( janiw aruskipaw qamawxakiti ukhamarak janiw qillqayaw qamawxakiti). Taqpach yanapanaka aruskipañawinakat aka qillqatata ukhamarak apnaqayaraktamwa.', # MODIF

	// O
	'onglet_messages_internes' => 'Manqhat yatiyawinaka',
	'onglet_messages_publics' => 'Yatiyawinak taqinir uñt’ayañataki ',
	'onglet_messages_vide' => 'Jan sawump yatiyawinaka',

	// R
	'repondre_message' => 'Aka yatiyawir jaysaña',

	// S
	'statut_original' => 'nayriri',

	// T
	'titre_forum' => 'Manqha aruskipañawi',
];
